## Website development setup

Install pnpm
```shell
curl -fsSL https://get.pnpm.io/install.sh | sh -
```

Install dependencies
```shell
pnpm i
```

Dev mode for the docs
```shell
pnpm docs:dev
```

## Website content development

Edit sidebars

- See `.vuepress/config.ts`.